<?php
/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 * By default it uses the theme name, in lowercase and without spaces, but this can be changed if needed.
 * If the identifier changes, it'll appear as if the options have been reset.
 */
 function optionsframework_option_name() {
    $optionsframework_settings = get_option('optionsframework');
    $optionsframework_settings['id'] = 'options_wp_castle_themes';
    update_option('optionsframework', $optionsframework_settings);
}

/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the 'id' fields, make sure to use all lowercase and no spaces.
 *
 * If you are making your theme translatable, you should replace 'wp_castle'
 * with the actual text domain for your theme.  Read more:
 * http://codex.wordpress.org/Function_Reference/load_theme_textdomain
 */

function optionsframework_options() {
	$options = array();

	//GENERAL	
	$options[] = array(
		'name'	=> __('General', 'wp_castle'),
		'type'	=> 'heading');

	$options[] = array(
		'name'	=> __('Custom Logo', 'wp_castle'),
		'desc'	=> __('Upload your custom logo. Max-width is 410px and Max-height is 60px', 'wp_castle'),
		'id'	=> 'custom_logo',
		'type'	=> 'upload');

	$options[] = array(
 		  'name' => __('Upload a Favicon', 'wp_castle'),
  	 	  'desc' => __('Upload a favicon on your theme, size must be 16px by 16px', 'wp_castle'),
  	  	 'id' => 'favicon_uploader',
  	 	  'type' => 'upload');

	$options[] = array(
		"name"	=> __('Header Ad', 'wp_castle'),
		"desc"	=> __('Use this field to add a 468x60 banner to your header.', 'wp_castle'),
		"id"	=> "header_ad",
		"std"	=> '<a href="#"><span class="default-ad"></span></a>',
		"type"	=> "textarea");

		return $options;
}

/*
 * This is an example of how to add custom scripts to the options panel.
 * This example shows/hides an option when a checkbox is clicked.
 */

 add_action('optionsframework_custom_scripts', 'optionsframework_custom_scripts');

function optionsframework_custom_scripts() { ?>
<script type="text/javascript">
jQuery(document).ready(function($) {
	$('#example_showhidden').click(function() {
  		$('#section-example_text_hidden').fadeToggle(400);
	});

	if ($('#example_showhidden:checked').val() !== undefined) {
		$('#section-example_text_hidden').show();
	}
});
</script>
<?php } ?>